@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -37,7 +37,7 @@ class LIBSIEVEEDITOR_EXPORT SieveEditorMainWindow : public KXmlGuiWindow
     Q_OBJECT
 public:
     explicit SieveEditorMainWindow(QWidget *parent = nullptr);
-    ~SieveEditorMainWindow();
+    ~SieveEditorMainWindow() override;
 
     QString currentHelpTitle() const;
     QUrl currentHelpUrl() const;
@@ -45,7 +45,7 @@ public:
 protected:
     void closeEvent(QCloseEvent *e) override;
 
-private Q_SLOTS:
+private:
     void slotConfigure();
     void slotAddServerSieve();
     void slotCreateNewScript();
